'use client'
import { deleteUsers } from "@/app/lib/users/action";
import AddButton from "@/components/buttons/add";
import DataTable from "@/components/tables/DataTable";
import { DeleteIcon, EditIcon } from "@chakra-ui/icons";
import { Button, Flex, Icon, useColorModeValue, useToast } from "@chakra-ui/react";
import { useRouter } from "next/navigation";
import { UserInterface } from "../type/user";
import { columnsDataBlocks } from "../variables/columnsBlock";
import { extractPagination } from "@/utils/common";
import { hasPermission } from "@/utils/navigation";
import { useGeneral } from "@/contexts/GeneralContext";

interface UserTableProps {
  data: { data: UserInterface[] };
}

const UsersTable: React.FC<UserTableProps> = ({ data }) => {
  const { currentUser } = useGeneral();
  const brandColor = useColorModeValue("brand.500", "white");
  const toast = useToast();
  const router = useRouter();

  const paginationData = extractPagination(data);

  const deleteUser = async (id: number) => {
    const res = await deleteUsers(id);
    if (res?.status == 200) {
      toast({
        title: "Success",
        description: res.message,
        status: "success",
        position: "top-right",
        duration: 2000,
        isClosable: true,
      });
      router.refresh();
    } else {
      toast({
        title: "Error",
        description: res.message,
        status: "error",
        position: "top-right",
        duration: 9000,
        isClosable: true,
      });
    }
  };

  const handleAddClick = () => {
    router.push("/admin/users/create");
  };

  const handleEditClick = (id: number) => {
    router.push(`/admin/users/edit/${id}`);
  };

  const action = (user: number) => (
    <Flex gap={2}>
      {hasPermission(currentUser.permissions, "user", "edit") && (
        <Button
          variant="blank"
          onClick={() => handleEditClick(user)}
          w="37px"
          h="37px"
          borderRadius="10px">
          <Icon as={EditIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}

      {hasPermission(currentUser.permissions, "user", "delete") && (
        <Button
          variant="blank"
          onClick={() => deleteUser(user)}
          w="37px"
          h="37px"
          borderRadius="10px">
          <Icon as={DeleteIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}

    </Flex>
  );

  return (
    <>
      <DataTable
        addButton={hasPermission(currentUser.permissions, "user", "create") && <AddButton onClick={handleAddClick} />}
        columnsData={columnsDataBlocks}
        tableData={data?.data as unknown as UserInterface[]}
        paginate={paginationData}
        isSelectable={false}
        showPageSize={false}
        actionSlot={(user: number) => action(user)}
      />
    </>
  );
};

export default UsersTable;
